@@ -198,7 +198,7 @@ void KSquaresWindow::gameOver(const QVector<KSquaresPlayer> &_playerList)
     //m_scene->displayScoreTable(playerList);
 
     ScoresDialog scoresDialog(this);
-    scoresDialog.setWindowTitle(i18n("Scores"));
+    scoresDialog.setWindowTitle(i18nc("@title:window", "Scores"));
 
     QStandardItemModel *scoreTableModel = new QStandardItemModel(&scoresDialog);
     scoreTableModel->setRowCount(playerList.size());
